Learn R Programming

algebraic.dist (version 0.9.1)

cdf: Generic method for obtaining the cdf of an object.

Description

Generic method for obtaining the cdf of an object.

Usage

cdf(x, ...)

Value

A function computing the cumulative distribution function.

Arguments

x

The object to obtain the cdf of.

...

Additional arguments to pass.

Examples

Run this code
x <- normal(0, 1)
F <- cdf(x)
F(0)    # 0.5 (median of standard normal)
F(1.96) # approximately 0.975

Run the code above in your browser using DataLab