cdf.empirical_dist: Method for obtaining the cdf of 'empirical_dist' object 'x'.

View source: R/empirical_dist.R

cdf.empirical_distR Documentation

Method for obtaining the cdf of empirical_dist object x.

Description

If x is a multivariate empirical distribution, this function will throw an error. It's only defined for univariate empirical distributions.

Usage

## S3 method for class 'empirical_dist'
cdf(x, ...)

Arguments

x

The empirical distribution object.

...

Additional arguments to pass (not used))

Value

A function that takes a numeric vector t and returns the empirical cdf of x evaluated at t.

Examples

ed <- empirical_dist(c(1, 2, 3, 4, 5))
Fx <- cdf(ed)
Fx(3) # 0.6
Fx(c(1, 5)) # 0.2, 1.0

algebraic.dist documentation built on Feb. 27, 2026, 5:06 p.m.