countable_set: Countable Set

countable_setR Documentation

Countable Set

Description

A countably infinite support set, such as the non-negative integers. It satisfies the concept of a support (see has, infimum, supremum, dim).

Public fields

lower_bound

Integer lower bound of the set.

Methods

Public methods


Method new()

Initialize a countable set.

Usage
countable_set$new(lower = 0L)
Arguments
lower

Integer lower bound (default 0).


Method clone()

The objects of this class are cloneable with this method.

Usage
countable_set$clone(deep = FALSE)
Arguments
deep

Whether to make a deep clone.


algebraic.dist documentation built on Feb. 27, 2026, 5:06 p.m.