| density.mvn | R Documentation |
mvn object (multivariate
normal).Function generator for obtaining the pdf of an mvn object (multivariate
normal).
## S3 method for class 'mvn'
density(x, ...)
x |
The |
... |
Additional arguments to pass into the generated function. |
A function that computes the pdf of the mvn distribution.
It accepts as input:
- obs: vector or matrix of quantiles. when x is a matrix, each row
is taken to be a quantile and columns correspond to the number of
dimensions, p.
- mu: a a vector denoting the population mean. Defaults to the
mean of x (an mvn object)
- sigma: a matrix denoting the variance-covariance of
observations. Defaults to the variance-covariance of x.
- log: logical, determines whether to compute the log of the pdf.
Defaults to FALSE.
- ...: any additional parameters to pass to dmvnorm.
X <- mvn(c(0, 0), diag(2))
f <- density(X)
f(c(0, 0))
f(c(1, 1))
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.