Learn R Programming

algebraic.dist (version 0.9.1)

dim.exponential: Method to obtain the dimension of an exponential object.

Description

Method to obtain the dimension of an exponential object.

Usage

# S3 method for exponential
dim(x)

Value

The dimension of the exponential object

Arguments

x

The exponential object to obtain the dimension of

Examples

Run this code
dim(exponential(rate = 1))

Run the code above in your browser using DataLab