dim.mvn: Method for obtaining the dimension of an 'mvn' object.

View source: R/mvn.R

dim.mvnR Documentation

Method for obtaining the dimension of an mvn object.

Description

Method for obtaining the dimension of an mvn object.

Usage

## S3 method for class 'mvn'
dim(x)

Arguments

x

The object to obtain the dimension of

Value

The dimension of the mvn object

Examples

dim(mvn(c(0, 0, 0)))

algebraic.dist documentation built on Feb. 27, 2026, 5:06 p.m.