dim.normal: Method for obtaining the dimension of a 'normal' object.

View source: R/normal.R

dim.normalR Documentation

Method for obtaining the dimension of a normal object.

Description

Method for obtaining the dimension of a normal object.

Usage

## S3 method for class 'normal'
dim(x)

Arguments

x

The normal object to obtain the dimension of

Value

The dimension of the normal object

Examples

dim(normal(0, 1))

algebraic.dist documentation built on Feb. 27, 2026, 5:06 p.m.