edist: Takes an expression 'e' and a list 'vars' and returns a lazy...

View source: R/edist.R

edistR Documentation

Takes an expression e and a list vars and returns a lazy edist (expression distribution object), that is a subclass of dist that can be used in place of a dist object.

Description

Takes an expression e and a list vars and returns a lazy edist (expression distribution object), that is a subclass of dist that can be used in place of a dist object.

Usage

edist(e, vars)

Arguments

e

the expression to evaluate against the arguments.

vars

the list of distributions (with variable names) to evaluate the expression e against.

Value

An edist object.

Examples

x <- normal(0, 1)
y <- normal(2, 3)
e <- edist(quote(x + y), list(x = x, y = y))
e

algebraic.dist documentation built on Feb. 27, 2026, 5:06 p.m.