expectation: Generic method for obtaining the expectation of 'f' with...

View source: R/generic_dist.R

expectationR Documentation

Generic method for obtaining the expectation of f with respect to x.

Description

Generic method for obtaining the expectation of f with respect to x.

Usage

expectation(x, g, ...)

Arguments

x

The distribution object.

g

The function to take the expectation of.

...

Additional arguments to pass into g.

Value

The expected value of g(x).

Examples


x <- exponential(1)
# E[X] for Exp(1) is 1
expectation(x, function(t) t)


algebraic.dist documentation built on Feb. 27, 2026, 5:06 p.m.