has.countable_set: Check membership in a countable set.

View source: R/countable_set.R

has.countable_setR Documentation

Check membership in a countable set.

Description

Returns TRUE if all values are integers (within floating-point tolerance) that are at least as large as the lower bound.

Usage

## S3 method for class 'countable_set'
has(object, x)

Arguments

object

A countable_set object.

x

Value(s) to check.

Value

Logical; TRUE if all values are valid members of the set.

Examples

cs <- countable_set$new(0L)
has(cs, c(0, 3, 5))   # TRUE
has(cs, c(-1, 2))     # FALSE (negative integer)
has(cs, 1.5)          # FALSE (not integer)

algebraic.dist documentation built on Feb. 27, 2026, 5:06 p.m.