has.finite_set: Determine if a value is contained in the finite set.

View source: R/finite_set.R

has.finite_setR Documentation

Determine if a value is contained in the finite set.

Description

Determine if a value is contained in the finite set.

Usage

## S3 method for class 'finite_set'
has(object, x)

Arguments

object

A finite set.

x

A vector of values.

Value

Logical indicating membership.

Examples

fs <- finite_set$new(c(1, 3, 5, 7))
has(fs, 3) # TRUE
has(fs, 4) # FALSE

algebraic.dist documentation built on Feb. 27, 2026, 5:06 p.m.