has.interval: Determine if a value is contained in the interval.

View source: R/interval.R

has.intervalR Documentation

Determine if a value is contained in the interval.

Description

Determine if a value is contained in the interval.

Usage

## S3 method for class 'interval'
has(object, x)

Arguments

object

An interval object.

x

A vector of values.

Value

Logical vector indicating containment.

Examples

iv <- interval$new(lower = 0, upper = 1)
has(iv, 0.5) # TRUE
has(iv, 2.0) # FALSE

algebraic.dist documentation built on Feb. 27, 2026, 5:06 p.m.