hazard: Generic method for obtaining the hazard function of an...

View source: R/generic_dist.R

hazardR Documentation

Generic method for obtaining the hazard function of an object.

Description

Generic method for obtaining the hazard function of an object.

Usage

hazard(x, ...)

Arguments

x

The object to obtain the hazard function of.

...

Additional arguments to pass.

Value

A function computing the hazard rate at given points.

Examples

x <- exponential(2)
h <- hazard(x)
h(1)  # hazard rate at t = 1 (constant for exponential)

algebraic.dist documentation built on Feb. 27, 2026, 5:06 p.m.