hazard.chi_squared: Method for obtaining the hazard function of a 'chi_squared'...

View source: R/chi_squared.R

hazard.chi_squaredR Documentation

Method for obtaining the hazard function of a chi_squared object.

Description

Method for obtaining the hazard function of a chi_squared object.

Usage

## S3 method for class 'chi_squared'
hazard(x, ...)

Arguments

x

The chi_squared object

...

Additional arguments (not used)

Value

A function that computes h(t) = f(t) / S(t)

Examples

x <- chi_squared(5)
h <- hazard(x)
h(5)

algebraic.dist documentation built on Feb. 27, 2026, 5:06 p.m.