hazard.exponential: Method to obtain the hazard function of an 'exponential'...

View source: R/exponential.R

hazard.exponentialR Documentation

Method to obtain the hazard function of an exponential object.

Description

Method to obtain the hazard function of an exponential object.

Usage

## S3 method for class 'exponential'
hazard(x, ...)

Arguments

x

The exponential object to obtain the hazard function of

...

Additional arguments (not used)

Value

A function that computes the hazard function of the exponential distribution at a given point t and rate rate. By default, rate is the failure rate of object x Also accepts a log argument that determines whether to compute the log of the hazard function.

Examples

x <- exponential(rate = 2)
h <- hazard(x)
h(1)
h(5)

algebraic.dist documentation built on Feb. 27, 2026, 5:06 p.m.