hazard.gamma_dist: Method for obtaining the hazard function of a 'gamma_dist'...

View source: R/gamma_dist.R

hazard.gamma_distR Documentation

Method for obtaining the hazard function of a gamma_dist object.

Description

Method for obtaining the hazard function of a gamma_dist object.

Usage

## S3 method for class 'gamma_dist'
hazard(x, ...)

Arguments

x

The gamma_dist object

...

Additional arguments (not used)

Value

A function that computes h(t) = f(t) / S(t)

Examples

x <- gamma_dist(shape = 2, rate = 1)
h <- hazard(x)
h(1)

algebraic.dist documentation built on Feb. 27, 2026, 5:06 p.m.