View source: R/empirical_dist.R
| inv_cdf.empirical_dist | R Documentation |
empirical_dist object.Uses the empirical quantile function from the observed data.
## S3 method for class 'empirical_dist'
inv_cdf(x, ...)
x |
The empirical distribution object. |
... |
Additional arguments (not used). |
A function that accepts a vector of probabilities p and returns
the corresponding quantiles.
ed <- empirical_dist(c(1, 2, 3, 4, 5))
qf <- inv_cdf(ed)
qf(0.5) # median
qf(c(0.25, 0.75)) # quartiles
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.