inv_cdf.exponential: Method to obtain the inverse cdf of an 'exponential' object.

View source: R/exponential.R

inv_cdf.exponentialR Documentation

Method to obtain the inverse cdf of an exponential object.

Description

Method to obtain the inverse cdf of an exponential object.

Usage

## S3 method for class 'exponential'
inv_cdf(x, ...)

Arguments

x

The object to obtain the inverse cdf of

...

Additional arguments (not used)

Value

A function that computes the inverse cdf of the exponential distribution. Accepts as input a vector p probabilities to compute the inverse cdf, a rate value denoting the failure rate of the exponential distribution, and a logical log.p indicating whether input p denotes probability or log-probability. By default, rate is the failure rate of object x.

Examples

x <- exponential(rate = 1)
q <- inv_cdf(x)
q(0.5)
q(0.95)

algebraic.dist documentation built on Feb. 27, 2026, 5:06 p.m.