inv_cdf.normal: Method for obtaining the inverse cdf of an 'normal' object.

View source: R/normal.R

inv_cdf.normalR Documentation

Method for obtaining the inverse cdf of an normal object.

Description

Method for obtaining the inverse cdf of an normal object.

Usage

## S3 method for class 'normal'
inv_cdf(x, ...)

Arguments

x

The object to obtain the inverse cdf of

...

Additional arguments to pass (not used)

Value

A function that computes the inverse cdf of the normal distribution.

Examples

x <- normal(0, 1)
q <- inv_cdf(x)
q(0.5)
q(0.975)

algebraic.dist documentation built on Feb. 27, 2026, 5:06 p.m.