is_dist: Function to determine whether an object 'x' is a 'dist'...

View source: R/dist.R

is_distR Documentation

Function to determine whether an object x is a dist object.

Description

Function to determine whether an object x is a dist object.

Usage

is_dist(x)

Arguments

x

The object to test

Value

Logical indicating whether x is a dist object.

Examples

is_dist(normal(0, 1))   # TRUE
is_dist(42)             # FALSE

algebraic.dist documentation built on Feb. 27, 2026, 5:06 p.m.