is_edist: Function to determine whether an object 'x' is an 'edist'...

View source: R/edist.R

is_edistR Documentation

Function to determine whether an object x is an edist object.

Description

Function to determine whether an object x is an edist object.

Usage

is_edist(x)

Arguments

x

The object to test

Value

Logical; TRUE if x is an edist.

Examples

is_edist(normal(0, 1) * exponential(1))  # TRUE
is_edist(normal(0, 1))                   # FALSE

algebraic.dist documentation built on Feb. 27, 2026, 5:06 p.m.