is_empirical_dist: Function to determine whether an object 'x' is an...

View source: R/empirical_dist.R

is_empirical_distR Documentation

Function to determine whether an object x is an empirical_dist object.

Description

Function to determine whether an object x is an empirical_dist object.

Usage

is_empirical_dist(x)

Arguments

x

The object to test

Value

Logical; TRUE if x is an empirical_dist.

Examples

ed <- empirical_dist(c(1, 2, 3))
is_empirical_dist(ed)    # TRUE
is_empirical_dist("abc") # FALSE

algebraic.dist documentation built on Feb. 27, 2026, 5:06 p.m.