is_exponential: Function to determine whether an object 'x' is an...

View source: R/exponential.R

is_exponentialR Documentation

Function to determine whether an object x is an exponential object.

Description

Function to determine whether an object x is an exponential object.

Usage

is_exponential(x)

Arguments

x

The object to test

Value

Logical; TRUE if x is an exponential.

Examples

is_exponential(exponential(1))
is_exponential(normal(0, 1))

algebraic.dist documentation built on Feb. 27, 2026, 5:06 p.m.