is_mvn: Function to determine whether an object 'x' is an 'mvn'...

View source: R/mvn.R

is_mvnR Documentation

Function to determine whether an object x is an mvn object.

Description

Function to determine whether an object x is an mvn object.

Usage

is_mvn(x)

Arguments

x

The object to test

Value

Logical; TRUE if x is an mvn.

Examples

is_mvn(mvn(c(0, 0)))
is_mvn(normal(0, 1))

algebraic.dist documentation built on Feb. 27, 2026, 5:06 p.m.