is_normal: Function to determine whether an object 'x' is an 'normal'...

View source: R/normal.R

is_normalR Documentation

Function to determine whether an object x is an normal object.

Description

Function to determine whether an object x is an normal object.

Usage

is_normal(x)

Arguments

x

The object to test

Value

Logical; TRUE if x is a normal.

Examples

is_normal(normal(0, 1))
is_normal(exponential(1))

algebraic.dist documentation built on Feb. 27, 2026, 5:06 p.m.