marginal.mvn: Generic method for obtaining the marginal distribution of an...

View source: R/mvn.R

marginal.mvnR Documentation

Generic method for obtaining the marginal distribution of an mvn object x over components indices.

Description

Generic method for obtaining the marginal distribution of an mvn object x over components indices.

Usage

## S3 method for class 'mvn'
marginal(x, indices)

Arguments

x

The mvn object.

indices

The indices of the marginal distribution to obtain.

Value

A normal (for a single index) or mvn marginal distribution.

Examples

X <- mvn(c(1, 2, 3))
# Univariate marginal
marginal(X, 1)
# Bivariate marginal
marginal(X, c(1, 3))

algebraic.dist documentation built on Feb. 27, 2026, 5:06 p.m.