Learn R Programming

algebraic.dist (version 0.9.1)

mean.edist: Method for obtaining the mean of an edist object.

Description

Method for obtaining the mean of an edist object.

Usage

# S3 method for edist
mean(x, n = 10000, ...)

Value

The mean of the edist object

Arguments

x

The edist object to retrieve the mean from

n

The number of samples to take (default: 10000)

...

Additional arguments to pass (not used)

Examples

Run this code
# \donttest{
set.seed(1)
z <- normal(0, 1) * exponential(2)
mean(z)
# }

Run the code above in your browser using DataLab