mean.exponential: Method to obtain the mean of an 'exponential' object.

View source: R/exponential.R

mean.exponentialR Documentation

Method to obtain the mean of an exponential object.

Description

Method to obtain the mean of an exponential object.

Usage

## S3 method for class 'exponential'
mean(x, ...)

Arguments

x

The exponential object to obtain the mean of

...

Additional arguments (not used)

Value

The mean of the exponential distribution (1 / rate).

Examples

x <- exponential(rate = 0.5)
mean(x)

algebraic.dist documentation built on Feb. 27, 2026, 5:06 p.m.