nobs.empirical_dist: Method for obtaining the number of observations used to...

View source: R/empirical_dist.R

nobs.empirical_distR Documentation

Method for obtaining the number of observations used to construct a empirical_dist object.

Description

Method for obtaining the number of observations used to construct a empirical_dist object.

Usage

## S3 method for class 'empirical_dist'
nobs(object, ...)

Arguments

object

The empirical distribution object.

...

Additional arguments to pass (not used).

Value

Integer; number of observations.

Examples

ed <- empirical_dist(c(10, 20, 30, 40))
nobs(ed) # 4

algebraic.dist documentation built on Feb. 27, 2026, 5:06 p.m.