nparams: Generic method for obtaining the number of parameters of...

View source: R/generic_dist.R

nparamsR Documentation

Generic method for obtaining the number of parameters of distribution-like object x.

Description

Generic method for obtaining the number of parameters of distribution-like object x.

Usage

nparams(x)

Arguments

x

the object to obtain the number of parameters for

Value

Integer; the number of parameters.

Examples

d <- empirical_dist(matrix(rnorm(30), ncol = 3))
nparams(d)  # 0 (non-parametric)

algebraic.dist documentation built on Feb. 27, 2026, 5:06 p.m.