nparams.mixture: Number of parameters for a 'mixture' distribution.

View source: R/mixture.R

nparams.mixtureR Documentation

Number of parameters for a mixture distribution.

Description

The total number of parameters is the sum of component parameters plus the number of mixing weights.

Usage

## S3 method for class 'mixture'
nparams(x)

Arguments

x

A mixture object.

Value

An integer count of parameters.

Examples

m <- mixture(list(normal(0, 1), normal(5, 2)), c(0.3, 0.7))
nparams(m)

algebraic.dist documentation built on Feb. 27, 2026, 5:06 p.m.