obs: Retrieve the observations used to construct a...

View source: R/generic_dist.R

obsR Documentation

Retrieve the observations used to construct a distribution-like object. This is useful for obtaining the data used to construct an empirical distribution, but it is also useful for, say, retrieving the sample that was used by a fitted object, like an maximum likelihood estimate.

Description

Retrieve the observations used to construct a distribution-like object. This is useful for obtaining the data used to construct an empirical distribution, but it is also useful for, say, retrieving the sample that was used by a fitted object, like an maximum likelihood estimate.

Usage

obs(x)

Arguments

x

the object to retrieve the observations from

Value

The data (matrix or vector) used to construct x.

Examples

d <- empirical_dist(1:10)
obs(d)  # returns the vector 1:10

algebraic.dist documentation built on Feb. 27, 2026, 5:06 p.m.