params: Generic method for obtaining the parameters of an object.

View source: R/generic_dist.R

paramsR Documentation

Generic method for obtaining the parameters of an object.

Description

Generic method for obtaining the parameters of an object.

Usage

params(x)

Arguments

x

The object to obtain the parameters of.

Value

A named vector (or list) of distribution parameters.

Examples

x <- normal(5, 2)
params(x)  # mu = 5, var = 2

y <- exponential(3)
params(y)  # rate = 3

algebraic.dist documentation built on Feb. 27, 2026, 5:06 p.m.