params.edist: Method for obtaining the parameters of an 'edist' object.

View source: R/edist.R

params.edistR Documentation

Method for obtaining the parameters of an edist object.

Description

Method for obtaining the parameters of an edist object.

Usage

## S3 method for class 'edist'
params(x)

Arguments

x

The object to obtain the parameters of

Value

A named vector of parameters

Examples

z <- normal(0, 1) * exponential(2)
params(z)

algebraic.dist documentation built on Feb. 27, 2026, 5:06 p.m.