params.exponential: Method for obtaining the parameters of an 'exponential'...

View source: R/exponential.R

params.exponentialR Documentation

Method for obtaining the parameters of an exponential object.

Description

Method for obtaining the parameters of an exponential object.

Usage

## S3 method for class 'exponential'
params(x)

Arguments

x

The object to obtain the parameters of

Value

A named vector of parameters

Examples

x <- exponential(rate = 0.5)
params(x)

algebraic.dist documentation built on Feb. 27, 2026, 5:06 p.m.