params.mvn: Method for obtaining the parameters of a 'mvn' object.

View source: R/mvn.R

params.mvnR Documentation

Method for obtaining the parameters of a mvn object.

Description

Method for obtaining the parameters of a mvn object.

Usage

## S3 method for class 'mvn'
params(x)

Arguments

x

The object to obtain the parameters of

Value

A named vector of parameters

Examples

X <- mvn(c(0, 0), diag(2))
params(X)

algebraic.dist documentation built on Feb. 27, 2026, 5:06 p.m.