params.normal: Method for obtaining the parameters of a 'normal' object.

View source: R/normal.R

params.normalR Documentation

Method for obtaining the parameters of a normal object.

Description

Method for obtaining the parameters of a normal object.

Usage

## S3 method for class 'normal'
params(x)

Arguments

x

The object to obtain the parameters of

Value

A named vector of parameters

Examples

x <- normal(3, 2)
params(x)

algebraic.dist documentation built on Feb. 27, 2026, 5:06 p.m.