sample_mvn_region: Function for obtaining sample points for an mvn object that is within
the p-probability region. That is, it samples from the smallest region of
the distribution that contains p probability mass. This is done by first
sampling from the entire distribution, then rejecting samples that are not
in the probability region (using the statistical distance mahalanobis
from mu).
Description
Function for obtaining sample points for an mvn object that is within
the p-probability region. That is, it samples from the smallest region of
the distribution that contains p probability mass. This is done by first
sampling from the entire distribution, then rejecting samples that are not
in the probability region (using the statistical distance mahalanobis
from mu).
Usage
sample_mvn_region(n, mu, sigma, p = 0.95, ...)
Value
An n by length(mu) matrix of samples within the
probability region.