sampler.exponential: Method to sample from an 'exponential' object.

View source: R/exponential.R

sampler.exponentialR Documentation

Method to sample from an exponential object.

Description

Method to sample from an exponential object.

Usage

## S3 method for class 'exponential'
sampler(x, ...)

Arguments

x

The exponential object to sample from.

...

Additional arguments to pass (not used)

Value

A function that allows sampling from the exponential distribution. Accepts an argument n denoting sample size and rate denoting the failure rate. Defaults to the failure rate of object x.

Examples

x <- exponential(rate = 2)
s <- sampler(x)
set.seed(42)
s(5)

algebraic.dist documentation built on Feb. 27, 2026, 5:06 p.m.