sampler.normal: Method for sampling from a 'normal' object.

View source: R/normal.R

sampler.normalR Documentation

Method for sampling from a normal object.

Description

Method for sampling from a normal object.

Usage

## S3 method for class 'normal'
sampler(x, ...)

Arguments

x

The normal object to sample from

...

Additional arguments to pass (not used)

Value

A function that samples from the normal distribution. As input, it accepts a sample size n, a numeric mu, and a variance numeric var. By default, mu and var are the mean and variance of object x.

Examples

x <- normal(0, 1)
s <- sampler(x)
set.seed(42)
s(5)

algebraic.dist documentation built on Feb. 27, 2026, 5:06 p.m.