sup.exponential: Support for exponential distribution, the positive real...

View source: R/exponential.R

sup.exponentialR Documentation

Support for exponential distribution, the positive real numbers, (0, Inf).

Description

Support for exponential distribution, the positive real numbers, (0, Inf).

Usage

## S3 method for class 'exponential'
sup(x)

Arguments

x

The object to obtain the support of

Value

An interval object representing the support of the exponential

Examples

x <- exponential(rate = 1)
sup(x)

algebraic.dist documentation built on Feb. 27, 2026, 5:06 p.m.