sup.gamma_dist: Support for gamma distribution, the positive real numbers (0,...

View source: R/gamma_dist.R

sup.gamma_distR Documentation

Support for gamma distribution, the positive real numbers (0, Inf).

Description

Support for gamma distribution, the positive real numbers (0, Inf).

Usage

## S3 method for class 'gamma_dist'
sup(x)

Arguments

x

The gamma_dist object

Value

An interval object representing (0, Inf)

Examples

sup(gamma_dist(2, 1))

algebraic.dist documentation built on Feb. 27, 2026, 5:06 p.m.