sup.normal: Method for obtaining the support of a 'normal' object, where...

View source: R/normal.R

sup.normalR Documentation

Method for obtaining the support of a normal object, where the support is defined as values that have non-zero probability density.

Description

Method for obtaining the support of a normal object, where the support is defined as values that have non-zero probability density.

Usage

## S3 method for class 'normal'
sup(x)

Arguments

x

The normal object to obtain the support of

Value

A support-type object (see support.R), in this case an interval object for each component.

Examples

x <- normal(0, 1)
sup(x)

algebraic.dist documentation built on Feb. 27, 2026, 5:06 p.m.