surv.chi_squared: Method for obtaining the survival function of a 'chi_squared'...

View source: R/chi_squared.R

surv.chi_squaredR Documentation

Method for obtaining the survival function of a chi_squared object.

Description

Method for obtaining the survival function of a chi_squared object.

Usage

## S3 method for class 'chi_squared'
surv(x, ...)

Arguments

x

The chi_squared object

...

Additional arguments (not used)

Value

A function that computes S(t) = P(X > t)

Examples

x <- chi_squared(5)
S <- surv(x)
S(5)

algebraic.dist documentation built on Feb. 27, 2026, 5:06 p.m.