Learn R Programming

algebraic.dist (version 0.9.1)

surv.gamma_dist: Method for obtaining the survival function of a gamma_dist object.

Description

Method for obtaining the survival function of a gamma_dist object.

Usage

# S3 method for gamma_dist
surv(x, ...)

Value

A function that computes S(t) = P(X > t)

Arguments

x

The gamma_dist object

...

Additional arguments (not used)

Examples

Run this code
x <- gamma_dist(shape = 2, rate = 1)
S <- surv(x)
S(1)

Run the code above in your browser using DataLab