| cdf.normal | R Documentation |
normal object.Method for obtaining the cdf of an normal object.
## S3 method for class 'normal'
cdf(x, ...)
x |
The object to obtain the cdf of |
... |
Additional arguments to pass (not used) |
A function that computes the cdf of the normal distribution.
It accepts as input a parameter vector q, a mean vector mu,
a variance var, and a log argument
determining whether to compute the log of the cdf. By default,
mu and var are the mean and variance of object x and log
is FALSE. Finally, it accepts additional arguments ... to
pass to the pnorm function.
x <- normal(0, 1)
F <- cdf(x)
F(0)
F(1.96)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.