A function that computes the cdf of the normal distribution.
It accepts as input a parameter vector q, a mean vector mu,
a variance var, and a log argument
determining whether to compute the log of the cdf. By default,
mu and var are the mean and variance of object x and log
is FALSE. Finally, it accepts additional arguments ... to
pass to the pnorm function.