| countable_set | R Documentation |
A countably infinite support set, such as the non-negative
integers. It satisfies the concept of a support (see has,
infimum, supremum, dim).
lower_boundInteger lower bound of the set.
new()Initialize a countable set.
countable_set$new(lower = 0L)
lowerInteger lower bound (default 0).
clone()The objects of this class are cloneable with this method.
countable_set$clone(deep = FALSE)
deepWhether to make a deep clone.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.