density.exponential: Method to obtain the pdf of an exponential object.
Description
Method to obtain the pdf of an exponential object.
Usage
# S3 method for exponential
density(x, ...)
Value
A function that computes the pdf of the exponential distribution
at a given point t. Also accepts a rate argument that
determines the failure rate of the exponential distribution (defaults
to the failure rate of object x) and a log argument that determines
whether to compute the log of the pdf.