density.mvn: Function generator for obtaining the pdf of an mvn object (multivariate
normal).
Description
Function generator for obtaining the pdf of an mvn object (multivariate
normal).
Usage
# S3 method for mvn
density(x, ...)
Value
A function that computes the pdf of the mvn distribution.
It accepts as input:
- obs: vector or matrix of quantiles. when x is a matrix, each row
is taken to be a quantile and columns correspond to the number of
dimensions, p.
- mu: a a vector denoting the population mean. Defaults to the
mean of x (an mvn object)
- sigma: a matrix denoting the variance-covariance of
observations. Defaults to the variance-covariance of x.
- log: logical, determines whether to compute the log of the pdf.
Defaults to FALSE.
- ...: any additional parameters to pass to dmvnorm.
Arguments
x
The mvn (S3) object to obtain the pdf (density) of
...
Additional arguments to pass into the generated function.