| density.normal | R Documentation |
normal object.Method for obtaining the pdf of an normal object.
## S3 method for class 'normal'
density(x, ...)
x |
The object to obtain the pdf of |
... |
Additional arguments to pass (not used) |
A function that computes the pdf of the normal distribution.
It accepts as input a parameter vector x, a mean vector mu,
a variance-covariance matrix var, and a log argument
determining whether to compute the log of the pdf. By default,
mu and var are the mean and variance of object x.
x <- normal(0, 1)
f <- density(x)
f(0)
f(1)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.