A function that computes the pdf of the normal distribution.
It accepts as input a parameter vector x, a mean vector mu,
a variance-covariance matrix var, and a log argument
determining whether to compute the log of the pdf. By default,
mu and var are the mean and variance of object x.