Learn R Programming

algebraic.dist (version 0.9.1)

dim.mvn: Method for obtaining the dimension of an mvn object.

Description

Method for obtaining the dimension of an mvn object.

Usage

# S3 method for mvn
dim(x)

Value

The dimension of the mvn object

Arguments

x

The object to obtain the dimension of

Examples

Run this code
dim(mvn(c(0, 0, 0)))

Run the code above in your browser using DataLab