Learn R Programming

algebraic.dist (version 0.9.1)

dim.normal: Method for obtaining the dimension of a normal object.

Description

Method for obtaining the dimension of a normal object.

Usage

# S3 method for normal
dim(x)

Value

The dimension of the normal object

Arguments

x

The normal object to obtain the dimension of

Examples

Run this code
dim(normal(0, 1))

Run the code above in your browser using DataLab