| edist | R Documentation |
e and a list vars and returns a
lazy edist (expression distribution object), that is a subclass
of dist that can be used in place of a dist object.Takes an expression e and a list vars and returns a
lazy edist (expression distribution object), that is a subclass
of dist that can be used in place of a dist object.
edist(e, vars)
e |
the expression to evaluate against the arguments. |
vars |
the list of distributions (with variable names)
to evaluate the expression |
An edist object.
x <- normal(0, 1)
y <- normal(2, 3)
e <- edist(quote(x + y), list(x = x, y = y))
e
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.