Learn R Programming

algebraic.dist (version 0.9.1)

edist: Takes an expression e and a list vars and returns a lazy edist (expression distribution object), that is a subclass of dist that can be used in place of a dist object.

Description

Takes an expression e and a list vars and returns a lazy edist (expression distribution object), that is a subclass of dist that can be used in place of a dist object.

Usage

edist(e, vars)

Value

An edist object.

Arguments

e

the expression to evaluate against the arguments.

vars

the list of distributions (with variable names) to evaluate the expression e against.

Examples

Run this code
x <- normal(0, 1)
y <- normal(2, 3)
e <- edist(quote(x + y), list(x = x, y = y))
e

Run the code above in your browser using DataLab