Learn R Programming

algebraic.dist (version 0.9.1)

expectation.univariate_dist: Method for obtaining the expectation of f with respect to a univariate_dist object x.

Description

Assumes the support is a contiguous interval that has operations for retrieving the lower and upper bounds.

Usage

# S3 method for univariate_dist
expectation(x, g, ..., control = list())

Value

The expected value (numeric scalar), or the full integrate() result if compute_stats = TRUE.

Arguments

x

The distribution object.

g

The function to take the expectation of.

...

Additional arguments to pass into g.

control

An (optional) list of control parameters for integrate or expectation_data (if x is not continuous)

Examples

Run this code
x <- normal(3, 4)
# E[X] for Normal(3, 4) is 3
expectation(x, function(t) t)

# E[X^2] for Exp(1) is 2
expectation(exponential(1), function(t) t^2)

Run the code above in your browser using DataLab