Returns TRUE if all values are integers (within floating-point
tolerance) that are at least as large as the lower bound.
# S3 method for class 'countable_set'
has(object, x)
Arguments
- object
A countable_set object.
- x
Value(s) to check.
Value
Logical; TRUE if all values are valid members of the set.
Examples
cs <- countable_set$new(0L)
has(cs, c(0, 3, 5)) # TRUE
#> [1] TRUE
has(cs, c(-1, 2)) # FALSE (negative integer)
#> [1] FALSE
has(cs, 1.5) # FALSE (not integer)
#> [1] FALSE