View source: R/countable_set.R
| has.countable_set | R Documentation |
Returns TRUE if all values are integers (within floating-point
tolerance) that are at least as large as the lower bound.
## S3 method for class 'countable_set'
has(object, x)
object |
A |
x |
Value(s) to check. |
Logical; TRUE if all values are valid members of the set.
cs <- countable_set$new(0L)
has(cs, c(0, 3, 5)) # TRUE
has(cs, c(-1, 2)) # FALSE (negative integer)
has(cs, 1.5) # FALSE (not integer)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.