powered by
Returns TRUE if all values are integers (within floating-point tolerance) that are at least as large as the lower bound.
TRUE
# S3 method for countable_set has(object, x)
Logical; TRUE if all values are valid members of the set.
A countable_set object.
countable_set
Value(s) to check.
cs <- countable_set$new(0L) has(cs, c(0, 3, 5)) # TRUE has(cs, c(-1, 2)) # FALSE (negative integer) has(cs, 1.5) # FALSE (not integer)
Run the code above in your browser using DataLab