| hazard | R Documentation |
Generic method for obtaining the hazard function of an object.
hazard(x, ...)
x |
The object to obtain the hazard function of. |
... |
Additional arguments to pass. |
A function computing the hazard rate at given points.
x <- exponential(2)
h <- hazard(x)
h(1) # hazard rate at t = 1 (constant for exponential)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.