Learn R Programming

algebraic.dist (version 0.9.1)

hazard: Generic method for obtaining the hazard function of an object.

Description

Generic method for obtaining the hazard function of an object.

Usage

hazard(x, ...)

Value

A function computing the hazard rate at given points.

Arguments

x

The object to obtain the hazard function of.

...

Additional arguments to pass.

Examples

Run this code
x <- exponential(2)
h <- hazard(x)
h(1)  # hazard rate at t = 1 (constant for exponential)

Run the code above in your browser using DataLab