powered by
Generic method for obtaining the hazard function of an object.
hazard(x, ...)
A function computing the hazard rate at given points.
The object to obtain the hazard function of.
Additional arguments to pass.
x <- exponential(2) h <- hazard(x) h(1) # hazard rate at t = 1 (constant for exponential)
Run the code above in your browser using DataLab