A function that computes the hazard function of the
exponential distribution at a given point t and rate rate.
By default, rate is the failure rate of object x
Also accepts a log argument that determines whether
to compute the log of the hazard function.