Learn R Programming

algebraic.dist (version 0.9.1)

hazard.gamma_dist: Method for obtaining the hazard function of a gamma_dist object.

Description

Method for obtaining the hazard function of a gamma_dist object.

Usage

# S3 method for gamma_dist
hazard(x, ...)

Value

A function that computes h(t) = f(t) / S(t)

Arguments

x

The gamma_dist object

...

Additional arguments (not used)

Examples

Run this code
x <- gamma_dist(shape = 2, rate = 1)
h <- hazard(x)
h(1)

Run the code above in your browser using DataLab