empirical_dist object.R/empirical_dist.R
inv_cdf.empirical_dist.RdUses the empirical quantile function from the observed data.
# S3 method for class 'empirical_dist'
inv_cdf(x, ...)A function that accepts a vector of probabilities p and returns
the corresponding quantiles.