| inv_cdf.exponential | R Documentation |
exponential object.Method to obtain the inverse cdf of an exponential object.
## S3 method for class 'exponential'
inv_cdf(x, ...)
x |
The object to obtain the inverse cdf of |
... |
Additional arguments (not used) |
A function that computes the inverse cdf of the exponential
distribution. Accepts as input a vector p probabilities
to compute the inverse cdf, a rate value denoting the
failure rate of the exponential distribution, and a logical
log.p indicating whether input p denotes probability
or log-probability. By default, rate is the failure rate
of object x.
x <- exponential(rate = 1)
q <- inv_cdf(x)
q(0.5)
q(0.95)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.