Learn R Programming

algebraic.dist (version 0.9.1)

inv_cdf.exponential: Method to obtain the inverse cdf of an exponential object.

Description

Method to obtain the inverse cdf of an exponential object.

Usage

# S3 method for exponential
inv_cdf(x, ...)

Value

A function that computes the inverse cdf of the exponential distribution. Accepts as input a vector p probabilities to compute the inverse cdf, a rate value denoting the failure rate of the exponential distribution, and a logical log.p indicating whether input p denotes probability or log-probability. By default, rate is the failure rate of object x.

Arguments

x

The object to obtain the inverse cdf of

...

Additional arguments (not used)

Examples

Run this code
x <- exponential(rate = 1)
q <- inv_cdf(x)
q(0.5)
q(0.95)

Run the code above in your browser using DataLab