Method for obtaining the inverse cdf of an normal object.

# S3 method for class 'normal'
inv_cdf(x, ...)

Arguments

x

The object to obtain the inverse cdf of

...

Additional arguments to pass (not used)

Value

A function that computes the inverse cdf of the normal distribution.

Examples

x <- normal(0, 1)
q <- inv_cdf(x)
q(0.5)
#> [1] 0
q(0.975)
#> [1] 1.959964