| inv_cdf.normal | R Documentation |
normal object.Method for obtaining the inverse cdf of an normal object.
## S3 method for class 'normal'
inv_cdf(x, ...)
x |
The object to obtain the inverse cdf of |
... |
Additional arguments to pass (not used) |
A function that computes the inverse cdf of the normal distribution.
x <- normal(0, 1)
q <- inv_cdf(x)
q(0.5)
q(0.975)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.