Learn R Programming

algebraic.dist (version 0.9.1)

inv_cdf.normal: Method for obtaining the inverse cdf of an normal object.

Description

Method for obtaining the inverse cdf of an normal object.

Usage

# S3 method for normal
inv_cdf(x, ...)

Value

A function that computes the inverse cdf of the normal distribution.

Arguments

x

The object to obtain the inverse cdf of

...

Additional arguments to pass (not used)

Examples

Run this code
x <- normal(0, 1)
q <- inv_cdf(x)
q(0.5)
q(0.975)

Run the code above in your browser using DataLab