powered by
normal
Method for obtaining the inverse cdf of an normal object.
# S3 method for normal inv_cdf(x, ...)
A function that computes the inverse cdf of the normal distribution.
The object to obtain the inverse cdf of
Additional arguments to pass (not used)
x <- normal(0, 1) q <- inv_cdf(x) q(0.5) q(0.975)
Run the code above in your browser using DataLab