Learn R Programming

algebraic.dist (version 0.9.1)

is_dist: Function to determine whether an object x is a dist object.

Description

Function to determine whether an object x is a dist object.

Usage

is_dist(x)

Value

Logical indicating whether x is a dist object.

Arguments

x

The object to test

Examples

Run this code
is_dist(normal(0, 1))   # TRUE
is_dist(42)             # FALSE

Run the code above in your browser using DataLab