Learn R Programming

algebraic.dist (version 0.9.1)

is_edist: Function to determine whether an object x is an edist object.

Description

Function to determine whether an object x is an edist object.

Usage

is_edist(x)

Value

Logical; TRUE if x is an edist.

Arguments

x

The object to test

Examples

Run this code
is_edist(normal(0, 1) * exponential(1))  # TRUE
is_edist(normal(0, 1))                   # FALSE

Run the code above in your browser using DataLab