Learn R Programming

algebraic.dist (version 0.9.1)

is_empirical_dist: Function to determine whether an object x is an empirical_dist object.

Description

Function to determine whether an object x is an empirical_dist object.

Usage

is_empirical_dist(x)

Value

Logical; TRUE if x is an empirical_dist.

Arguments

x

The object to test

Examples

Run this code
ed <- empirical_dist(c(1, 2, 3))
is_empirical_dist(ed)    # TRUE
is_empirical_dist("abc") # FALSE

Run the code above in your browser using DataLab