Learn R Programming

algebraic.dist (version 0.9.1)

is_exponential: Function to determine whether an object x is an exponential object.

Description

Function to determine whether an object x is an exponential object.

Usage

is_exponential(x)

Value

Logical; TRUE if x is an exponential.

Arguments

x

The object to test

Examples

Run this code
is_exponential(exponential(1))
is_exponential(normal(0, 1))

Run the code above in your browser using DataLab