Learn R Programming

algebraic.dist (version 0.9.1)

is_mvn: Function to determine whether an object x is an mvn object.

Description

Function to determine whether an object x is an mvn object.

Usage

is_mvn(x)

Value

Logical; TRUE if x is an mvn.

Arguments

x

The object to test

Examples

Run this code
is_mvn(mvn(c(0, 0)))
is_mvn(normal(0, 1))

Run the code above in your browser using DataLab