Learn R Programming

algebraic.dist (version 0.9.1)

is_normal: Function to determine whether an object x is an normal object.

Description

Function to determine whether an object x is an normal object.

Usage

is_normal(x)

Value

Logical; TRUE if x is a normal.

Arguments

x

The object to test

Examples

Run this code
is_normal(normal(0, 1))
is_normal(exponential(1))

Run the code above in your browser using DataLab