Returns the degenerate limiting distribution of the sample mean \(\bar{X}_n\) under the Law of Large Numbers. The limit is a point mass at the population mean (represented as a normal or mvn with zero variance).

lln(base_dist)

Arguments

base_dist

A dist object representing the base distribution.

Value

A normal or mvn distribution with zero variance, representing the degenerate distribution at the mean.

Examples

# LLN for Exp(2): Xbar -> 1/2 (degenerate)
x <- exponential(rate = 2)
d <- lln(x)
mean(d)
#> [1] 0.5
vcov(d)
#> [1] 0