Learn R Programming

algebraic.dist (version 0.9.1)

lln: Law of Large Numbers Limiting Distribution

Description

Returns the degenerate limiting distribution of the sample mean \(\bar{X}_n\) under the Law of Large Numbers. The limit is a point mass at the population mean (represented as a normal or mvn with zero variance).

Usage

lln(base_dist)

Value

A normal or mvn distribution with zero variance, representing the degenerate distribution at the mean.

Arguments

base_dist

A dist object representing the base distribution.

Examples

Run this code
# LLN for Exp(2): Xbar -> 1/2 (degenerate)
x <- exponential(rate = 2)
d <- lln(x)
mean(d)
vcov(d)

Run the code above in your browser using DataLab