Learn R Programming

algebraic.dist (version 0.9.1)

lognormal: Construct a log-normal distribution object.

Description

Creates an S3 object representing a log-normal distribution with the given meanlog and sdlog parameters. The log-normal PDF is $$f(t) = \frac{1}{t \cdot sdlog \sqrt{2\pi}} \exp\!\left(-\frac{(\log t - meanlog)^2}{2 \cdot sdlog^2}\right)$$ for \(t > 0\).

Usage

lognormal(meanlog = 0, sdlog = 1)

Value

A lognormal object with classes c("lognormal", "univariate_dist", "continuous_dist", "dist").

Arguments

meanlog

Mean of the distribution on the log scale (default 0).

sdlog

Standard deviation on the log scale (default 1), must be positive.

Examples

Run this code
x <- lognormal(meanlog = 0, sdlog = 1)
mean(x)
vcov(x)
format(x)

Run the code above in your browser using DataLab