powered by
The marginal of a mixture is itself a mixture of the component marginals with the same mixing weights: \(p(x_I) = \sum_k w_k p_k(x_I)\).
# S3 method for mixture marginal(x, indices)
A mixture object with marginalized components.
mixture
A mixture object.
Integer vector of variable indices to keep.
Requires all components to support marginal.
marginal
# Mixture of bivariate normals, extract marginal over first variable m <- mixture( list(mvn(c(0, 0), diag(2)), mvn(c(3, 3), diag(2))), c(0.5, 0.5) ) m1 <- marginal(m, 1) mean(m1)
Run the code above in your browser using DataLab