Learn R Programming

algebraic.dist (version 0.9.1)

marginal.mvn: Generic method for obtaining the marginal distribution of an mvn object x over components indices.

Description

Generic method for obtaining the marginal distribution of an mvn object x over components indices.

Usage

# S3 method for mvn
marginal(x, indices)

Value

A normal (for a single index) or mvn marginal distribution.

Arguments

x

The mvn object.

indices

The indices of the marginal distribution to obtain.

Examples

Run this code
X <- mvn(c(1, 2, 3))
# Univariate marginal
marginal(X, 1)
# Bivariate marginal
marginal(X, c(1, 3))

Run the code above in your browser using DataLab