Learn R Programming

algebraic.dist (version 0.9.1)

mean.exponential: Method to obtain the mean of an exponential object.

Description

Method to obtain the mean of an exponential object.

Usage

# S3 method for exponential
mean(x, ...)

Value

The mean of the exponential distribution (1 / rate).

Arguments

x

The exponential object to obtain the mean of

...

Additional arguments (not used)

Examples

Run this code
x <- exponential(rate = 0.5)
mean(x)

Run the code above in your browser using DataLab