Learn R Programming

algebraic.dist (version 0.9.1)

nobs.empirical_dist: Method for obtaining the number of observations used to construct a empirical_dist object.

Description

Method for obtaining the number of observations used to construct a empirical_dist object.

Usage

# S3 method for empirical_dist
nobs(object, ...)

Value

Integer; number of observations.

Arguments

object

The empirical distribution object.

...

Additional arguments to pass (not used).

Examples

Run this code
ed <- empirical_dist(c(10, 20, 30, 40))
nobs(ed) # 4

Run the code above in your browser using DataLab