Generic method for obtaining the number of parameters of distribution-like object x.

nparams(x)

Arguments

x

the object to obtain the number of parameters for

Value

Integer; the number of parameters.

Examples

d <- empirical_dist(matrix(rnorm(30), ncol = 3))
nparams(d)  # 0 (non-parametric)
#> [1] 0