| nparams | R Documentation |
x.Generic method for obtaining the number of parameters of
distribution-like object x.
nparams(x)
x |
the object to obtain the number of parameters for |
Integer; the number of parameters.
d <- empirical_dist(matrix(rnorm(30), ncol = 3))
nparams(d) # 0 (non-parametric)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.