Learn R Programming

algebraic.dist (version 0.9.1)

nparams: Generic method for obtaining the number of parameters of distribution-like object x.

Description

Generic method for obtaining the number of parameters of distribution-like object x.

Usage

nparams(x)

Value

Integer; the number of parameters.

Arguments

x

the object to obtain the number of parameters for

Examples

Run this code
d <- empirical_dist(matrix(rnorm(30), ncol = 3))
nparams(d)  # 0 (non-parametric)

Run the code above in your browser using DataLab