powered by
x
Generic method for obtaining the number of parameters of distribution-like object x.
nparams(x)
Integer; the number of parameters.
the object to obtain the number of parameters for
d <- empirical_dist(matrix(rnorm(30), ncol = 3)) nparams(d) # 0 (non-parametric)
Run the code above in your browser using DataLab