| nparams.mixture | R Documentation |
mixture distribution.The total number of parameters is the sum of component parameters plus the number of mixing weights.
## S3 method for class 'mixture'
nparams(x)
x |
A |
An integer count of parameters.
m <- mixture(list(normal(0, 1), normal(5, 2)), c(0.3, 0.7))
nparams(m)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.