Learn R Programming

algebraic.dist (version 0.9.1)

nparams.mixture: Number of parameters for a mixture distribution.

Description

The total number of parameters is the sum of component parameters plus the number of mixing weights.

Usage

# S3 method for mixture
nparams(x)

Value

An integer count of parameters.

Arguments

x

A mixture object.

Examples

Run this code
m <- mixture(list(normal(0, 1), normal(5, 2)), c(0.3, 0.7))
nparams(m)

Run the code above in your browser using DataLab