powered by
mixture
The total number of parameters is the sum of component parameters plus the number of mixing weights.
# S3 method for mixture nparams(x)
An integer count of parameters.
A mixture object.
m <- mixture(list(normal(0, 1), normal(5, 2)), c(0.3, 0.7)) nparams(m)
Run the code above in your browser using DataLab