Retrieve the observations used to construct a distribution-like object. This is
useful for obtaining the data used to construct an empirical distribution, but
it is also useful for, say, retrieving the sample that was used by a fitted
object, like an maximum likelihood estimate.