Learn R Programming

algebraic.dist (version 0.9.1)

params: Generic method for obtaining the parameters of an object.

Description

Generic method for obtaining the parameters of an object.

Usage

params(x)

Value

A named vector (or list) of distribution parameters.

Arguments

x

The object to obtain the parameters of.

Examples

Run this code
x <- normal(5, 2)
params(x)  # mu = 5, var = 2

y <- exponential(3)
params(y)  # rate = 3

Run the code above in your browser using DataLab