Learn R Programming

algebraic.dist (version 0.9.1)

params.edist: Method for obtaining the parameters of an edist object.

Description

Method for obtaining the parameters of an edist object.

Usage

# S3 method for edist
params(x)

Value

A named vector of parameters

Arguments

x

The object to obtain the parameters of

Examples

Run this code
z <- normal(0, 1) * exponential(2)
params(z)

Run the code above in your browser using DataLab