Learn R Programming

algebraic.dist (version 0.9.1)

params.exponential: Method for obtaining the parameters of an exponential object.

Description

Method for obtaining the parameters of an exponential object.

Usage

# S3 method for exponential
params(x)

Value

A named vector of parameters

Arguments

x

The object to obtain the parameters of

Examples

Run this code
x <- exponential(rate = 0.5)
params(x)

Run the code above in your browser using DataLab