Learn R Programming

algebraic.dist (version 0.9.1)

params.mvn: Method for obtaining the parameters of a mvn object.

Description

Method for obtaining the parameters of a mvn object.

Usage

# S3 method for mvn
params(x)

Value

A named vector of parameters

Arguments

x

The object to obtain the parameters of

Examples

Run this code
X <- mvn(c(0, 0), diag(2))
params(X)

Run the code above in your browser using DataLab