Learn R Programming

algebraic.dist (version 0.9.1)

params.normal: Method for obtaining the parameters of a normal object.

Description

Method for obtaining the parameters of a normal object.

Usage

# S3 method for normal
params(x)

Value

A named vector of parameters

Arguments

x

The object to obtain the parameters of

Examples

Run this code
x <- normal(3, 2)
params(x)

Run the code above in your browser using DataLab