dist objects, or shifting a distribution by a scalar.R/edist.R
plus-.dist.RdCreates an expression distribution and automatically simplifies to closed form when possible (e.g., normal + normal = normal, normal + scalar = normal with shifted mean).
# S3 method for class 'dist'
x + yA simplified distribution or edist if no closed form exists