Learn R Programming

algebraic.dist (version 0.9.1)

rmap: Generic method for applying a map f to distribution object x.

Description

Generic method for applying a map f to distribution object x.

Usage

rmap(x, g, ...)

Value

A distribution representing the push-forward of x through g.

Arguments

x

The distribution object.

g

The function to apply.

...

Additional arguments to pass into g.

Examples

Run this code
# \donttest{
d <- empirical_dist(1:20)
d_sq <- rmap(d, function(x) x^2)
mean(d_sq)  # E[X^2] for uniform 1..20
# }

Run the code above in your browser using DataLab