| rmap.mvn | R Documentation |
g(x) where x is an mvn object.By the invariance property, if x is an mvn object,
then under the right conditions, asymptotically, g(x) is an MVN
distributed,
g(x) ~ normal(g(mean(x)), sigma)
where sigma is the variance-covariance of g(x)
## S3 method for class 'mvn'
rmap(x, g, n = 10000L, ...)
x |
The |
g |
The function to apply to |
n |
number of samples to take to estimate distribution of |
... |
additional arguments to pass into the |
An mvn distribution fitted to the transformed samples.
X <- mvn(c(1, 2), diag(2))
set.seed(42)
Y <- rmap(X, function(x) x^2)
mean(Y)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.