Method for obtaining the sampler of an edist object.
# S3 method for class 'edist'
sampler(x, ...)A function that takes a number of samples n, ...
which is passed into the expression x$e and returns
the result of applying the expression x$e to the
sampled values.
# \donttest{
set.seed(1)
z <- normal(0, 1) * exponential(2)
s <- sampler(z)
samples <- s(100)
head(samples)
#> [1] -0.23904851 0.14440946 -0.76695706 0.02963416 0.02068747 -0.58234762
# }