| sampler.edist | R Documentation |
edist object.Method for obtaining the sampler of an edist object.
## S3 method for class 'edist'
sampler(x, ...)
x |
The |
... |
Additional arguments to pass into each of the |
A function that takes a number of samples n, ...
which is passed into the expression x$e and returns
the result of applying the expression x$e to the
sampled values.
set.seed(1)
z <- normal(0, 1) * exponential(2)
s <- sampler(z)
samples <- s(100)
head(samples)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.