Learn R Programming

algebraic.dist (version 0.9.1)

sampler.edist: Method for obtaining the sampler of an edist object.

Description

Method for obtaining the sampler of an edist object.

Usage

# S3 method for edist
sampler(x, ...)

Value

A function that takes a number of samples n, ...

which is passed into the expression x$e and returns the result of applying the expression x$e to the sampled values.

Arguments

x

The edist object to obtain the sampler of.

...

Additional arguments to pass into each of the sampler function generators.

Examples

Run this code
# \donttest{
set.seed(1)
z <- normal(0, 1) * exponential(2)
s <- sampler(z)
samples <- s(100)
head(samples)
# }

Run the code above in your browser using DataLab