powered by
edist
Method for obtaining the sampler of an edist object.
# S3 method for edist sampler(x, ...)
A function that takes a number of samples n, ...
n
...
which is passed into the expression x$e and returns the result of applying the expression x$e to the sampled values.
x$e
The edist object to obtain the sampler of.
Additional arguments to pass into each of the sampler function generators.
sampler
# \donttest{ set.seed(1) z <- normal(0, 1) * exponential(2) s <- sampler(z) samples <- s(100) head(samples) # }
Run the code above in your browser using DataLab