Method for sampling from a normal object.

# S3 method for class 'normal'
sampler(x, ...)

Arguments

x

The normal object to sample from

...

Additional arguments to pass (not used)

Value

A function that samples from the normal distribution. As input, it accepts a sample size n, a numeric mu, and a variance numeric var. By default, mu and var are the mean and variance of object x.

Examples

x <- normal(0, 1)
s <- sampler(x)
set.seed(42)
s(5)
#> [1]  1.3709584 -0.5646982  0.3631284  0.6328626  0.4042683