| sampler.normal | R Documentation |
normal object.Method for sampling from a normal object.
## S3 method for class 'normal'
sampler(x, ...)
x |
The |
... |
Additional arguments to pass (not used) |
A function that samples from the normal distribution. As input,
it accepts a sample size n, a numeric mu, and a variance
numeric var. By default, mu and var are the mean and
variance of object x.
x <- normal(0, 1)
s <- sampler(x)
set.seed(42)
s(5)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.