sup: Generic method for retrieving the support of a (dist) object x.
Description
The returned value should have the following operations:
min: a vector, the minimum value of the support for each component.
max: a vector, the maximum value of the support for each component.
call: a predicate function, which returns TRUE if the value is in
the support, and FALSE otherwise.
sample: a function, which returns a sample from the support. Note that
the returned value is not guaranteed to be in the support of x. You may need
to call call to check.