R/exponential.R
sup.exponential.RdSupport for exponential distribution, the positive real numbers, (0, Inf).
# S3 method for class 'exponential'
sup(x)An interval object representing the support of the exponential
x <- exponential(rate = 1)
sup(x)
#> (0, Inf)