Learn R Programming

algebraic.dist (version 0.9.1)

sup.exponential: Support for exponential distribution, the positive real numbers, (0, Inf).

Description

Support for exponential distribution, the positive real numbers, (0, Inf).

Usage

# S3 method for exponential
sup(x)

Value

An interval object representing the support of the exponential

Arguments

x

The object to obtain the support of

Examples

Run this code
x <- exponential(rate = 1)
sup(x)

Run the code above in your browser using DataLab