powered by
Support for exponential distribution, the positive real numbers, (0, Inf).
# S3 method for exponential sup(x)
An interval object representing the support of the exponential
interval
The object to obtain the support of
x <- exponential(rate = 1) sup(x)
Run the code above in your browser using DataLab