Learn R Programming

algebraic.dist (version 0.9.1)

sup.gamma_dist: Support for gamma distribution, the positive real numbers (0, Inf).

Description

Support for gamma distribution, the positive real numbers (0, Inf).

Usage

# S3 method for gamma_dist
sup(x)

Value

An interval object representing (0, Inf)

Arguments

x

The gamma_dist object

Examples

Run this code
sup(gamma_dist(2, 1))

Run the code above in your browser using DataLab