Learn R Programming

algebraic.dist (version 0.9.1)

sup.normal: Method for obtaining the support of a normal object, where the support is defined as values that have non-zero probability density.

Description

Method for obtaining the support of a normal object, where the support is defined as values that have non-zero probability density.

Usage

# S3 method for normal
sup(x)

Value

A support-type object (see support.R), in this case an interval object for each component.

Arguments

x

The normal object to obtain the support of

Examples

Run this code
x <- normal(0, 1)
sup(x)

Run the code above in your browser using DataLab