Learn R Programming

algebraic.dist (version 0.9.1)

surv.chi_squared: Method for obtaining the survival function of a chi_squared object.

Description

Method for obtaining the survival function of a chi_squared object.

Usage

# S3 method for chi_squared
surv(x, ...)

Value

A function that computes S(t) = P(X > t)

Arguments

x

The chi_squared object

...

Additional arguments (not used)

Examples

Run this code
x <- chi_squared(5)
S <- surv(x)
S(5)

Run the code above in your browser using DataLab