A function that computes the cdf of the exponential. Accepts as
input a vector t at which to compute the cdf, an input rate
denoting the failure rate of the exponential distribution, and a
logical log indicating whether to compute the log of the cdf.
By default, rate is the failure rate of object x.